@@ -1,18 +1,28 @@
 import typing
+from base64 import b64decode
 from enum import Enum
+from io import BytesIO
+from mimetypes import guess_type
 
 from django.core.exceptions import ValidationError
+from django.core.files import File
 from django.forms import Field
 from django.utils.translation import gettext_lazy as _
 
 from .exceptions import RequestValidationError
 
 
+class IgnoreFillMixin:
+    @property
+    def ignore_fill(self) -> bool:
+        return True
+
+
 class BooleanField(Field):
     def to_python(self, value):
-        if value in (True, 'True', 'true', '1'):
+        if value in (True, 'True', 'true', '1', 1):
             return True
-        elif value in (False, 'False', 'false', '0'):
+        elif value in (False, 'False', 'false', '0', 0):
             return False
         else:
             return None
@@ -65,7 +75,7 @@ class FieldList(Field):
         return result
 
 
-class FormField(Field):
+class FormField(Field, IgnoreFillMixin):
     def __init__(self, form: typing.Type, **kwargs):
         self._form = form
 
@@ -86,7 +96,7 @@ class FormField(Field):
             raise RequestValidationError(form.errors)
 
 
-class FormFieldList(FormField):
+class FormFieldList(FormField, IgnoreFillMixin):
     default_error_messages = {
         'not_list': _('This field needs to be a list of objects!')
     }
@@ -177,3 +187,73 @@ class DictionaryField(Field):
 class AnyField(Field):
     def to_python(self, value) -> typing.Union[typing.Dict, typing.List]:
         return value
+
+
+class FileField(Field, IgnoreFillMixin):
+    default_error_messages = {
+        'max_length': _('Ensure this filename has at most %(max)d character (it has %(length)d).'),
+        'invalid_mime': _("The submitted file is empty."),
+    }
+
+    def __init__(self, max_length=None, mime: typing.List[str] = None, **kwargs):
+        self._max_length = max_length
+        self._mime = mime
+        super().__init__(**kwargs)
+
+    def to_python(self, value: str) -> typing.Optional[File]:
+        if not value:
+            return None
+
+        mime = None
+
+        if ',' in value:
+            mime, strict = guess_type(value)
+            value = value.split(',')[-1]
+
+        if self._mime and mime not in self._mime:
+            params = {'allowed': ', '.join(self._mime), 'received': mime}
+            raise ValidationError(self.error_messages['invalid_mime'], code='invalid_mime', params=params)
+
+        file = File(BytesIO(b64decode(value)))
+
+        if self._max_length is not None and file.size > self._max_length:
+            params = {'max': self._max_length, 'length': file.size}
+            raise ValidationError(self.error_messages['max_length'], code='max_length', params=params)
+
+        return file
+
+
+class ImageField(FileField, IgnoreFillMixin):
+    default_error_messages = {
+        'invalid_image': _("Upload a valid image. The file you uploaded was either not an image or a corrupted image.")
+    }
+
+    def to_python(self, value) -> typing.Optional[File]:
+        f = super(ImageField, self).to_python(value)
+
+        if f is None:
+            return None
+
+        # Pillow is required for ImageField
+        from PIL import Image
+
+        file = BytesIO(f.read())  # Create fp for Pillow
+
+        try:
+            image = Image.open(file)
+            image.verify()
+            f.image = image
+            f.content_type = Image.MIME.get(image.format)
+        except Exception:
+            raise ValidationError(
+                self.error_messages['invalid_image'],
+                code='invalid_image'
+            )
+
+        if self._mime and f.content_type not in self._mime:
+            params = {'allowed': ', '.join(self._mime), 'received': f.content_type}
+            raise ValidationError(self.error_messages['invalid_mime'], code='invalid_mime', params=params)
+
+        f.seek(0)  # Return to start of the file
+
+        return f
